Changelog
=========

0.1.1
-----
#. Added sites and subtitle fields.

0.1
---
#. Dependency cleanup.

0.0.6
-----
#. Added get_absolute_url on Category

0.0.5
-----
#. Use prepopulate_fields for admin interface
#. Parent category field added
#. South migration path created
#. Tree view of categories and tags

0.0.4 (2011-08-24)
------------------
#. Docs, testrunner.

